package enum_switch_demo;

/**
 * Card represents an immutable playing card.
 * 
 * @specfield suit : {Clubs,Diamonds,Hearts,Spades} // card suit
 * @specfield rank : {Ace,2,...,10,Jack,Queen,King} // card rank
 * 
 * @author Krysta Yousoufian, CSE 331 (adapted from examples by Marty Stepp and
 *         Michael Ernst)
 */
public class Card {

    // Abstraction function: a card r represents a playing card c such that...
    // c.suit = r.suit
    // c.rank = r.rank
    // Representation invariant: rank > 0 && rank <= 13

    private final Suit suit;

    // There is a very strong argument for making the rank an enum too. Enums
    // implement compareTo(), which compares values in the order they were
    // declared in the enum - useful for comparing ranks of cards.
    private final int rank;

    /**
     * @param rank
     *            The card's rank as an integer {1...13}, representing
     *            {Ace,2,...,10,Jack,Queen,King}
     * @param suit
     *            The card's suit
     * @requires 0 < rank <= 13
     * @effects Constructs a new card with the given suit and rank.
     */
    public Card(int rank, Suit suit) {
        if (rank < 1 || rank > 13)
            throw new IllegalArgumentException("Rank must be between 1 and 13");
        this.suit = suit;
        this.rank = rank;
        checkRep();
    }

    /**
     * @return This card's suit.
     */
    public Suit getSuit() {
        return suit;
    }

    /**
     * @return This card's rank as an integer {1...13}, representing
     *         {Ace,2,...,10,Jack,Queen,King}.
     */
    public int getRank() {
        return rank;
    }

    // Verify the rep invariant.
    private void checkRep() {
        assert rank > 0 && rank <= 13;
    }
}
