package observer_demo;

import java.util.ArrayList;
import java.util.List;
import java.util.Observable;
import java.util.Timer;
import java.util.TimerTask;

/**
 * Simulation of a news feed model that communicates with a remote content
 * provider to get news headlines. A new headline is "received" from a
 * hard-coded list at regular intervals to simulate receiving a new headline
 * from the content provider.
 * 
 * 
 * @author Krysta Yousoufian, CSE 331
 * 
 */
public class NewsFeed extends Observable {
    /** Frequency at which our simulated feed "receives" a news article, in ms. */
    public static final long NEWS_FREQUENCY = 2000;

    // Hard-coded list of headlines to be "received" from the content provider,
    // in order.
    private static final String[] headlines = {
            "Huskies beat Cougars! (Wait, that's not news.)",
            "CSE 331 voted best class EVER",
            "Cougars beat Huskies (whaaaaaat?)",
            "Justin Bieber elected US President",
            "OMG the apocalypse is here!!!",
            "All clear - apocalypse has passed",
            "UW CSE admitting more students next year" };

    // Headlines yet to be received from the hypothetical content provider.
    private List<String> remainingNews;
    // Periodically reports the receipt of a new headline from the hypothetical
    // content provider.
    private Timer newsTimer;

    /**
     * @effects Constructs a new NewsFeed that has not yet received any
     *          headlines.
     */
    public NewsFeed() {
        newsTimer = new Timer();
        remainingNews = new ArrayList<String>();
        for (String headline : headlines)
            remainingNews.add(headline);
    }

    /**
     * @effects Starts the simulation of a news article being received every
     *          NEWS_FREQUENCY ms from a hypothetical news provider. Continues
     *          until all headlines have been "received."
     */
    public void startSimulation() {
        TimerTask newsTask = new TimerTask() {
            public void run() {
                if (remainingNews.isEmpty()) {
                    newsTimer.cancel();
                } else {
                    String headline = remainingNews.remove(0);
                    NewsArticle article = new NewsArticle(headline);
                    setChanged();
                    notifyObservers(article);
                }
            }
        };
        newsTimer.scheduleAtFixedRate(newsTask, 0, NEWS_FREQUENCY);
    }
}
