package observer_demo;

import java.util.Observable;
import java.util.Observer;

/**
 * Text interface for the news feed that prints out headlines as they are
 * received.
 * 
 * @author Krysta Yousoufian, CSE 331
 * 
 */
public class NewsFeedTextUI implements Observer {

    /**
     * @effects Constructs a new text UI and prints a header for the news feed.
     */
    public NewsFeedTextUI() {
        System.out.println("CSE 331 News Feed");
        System.out.println("All the news that's fit to print!");
        System.out.println();
    }

    /**
     * @effects If arg is a NewsArticle, prints the article's headline and URL.
     */
    @Override
    public void update(Observable o, Object arg) {
        // For an Observable with multiple events, arg could be an enum value
        // representing the event type. If the event needs to contain some data
        // (such as the article), the arg's class could represent the event type.
        // (For example, NewsArticle indicates the event of the news feed
        // receiving a new article.)
        if (!(arg instanceof NewsArticle))
            return;

        NewsArticle article = (NewsArticle) arg;
        System.out.println("-----------------------------------------------");
        System.out.println(article.getHeadline());
        System.out.println("  Read more at " + article.getUrl() + "");
    }
}
