package visitor_demo.book;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * Represents a book as a title and list of chapters.
 * 
 * @author Krysta Yousoufian, CSE 331
 * 
 */
public class Book implements Text {
    private String title;
    private List<Chapter> chapters;

    /**
     * @param title
     *            The book title.
     * @param chapters
     *            The book's chapters, in order.
     * @effects Constructs a new Book with the given title and chapters.
     */
    public Book(String title, List<Chapter> chapters) {
        this.title = title;
        this.chapters = new ArrayList<Chapter>(chapters);
    }

    /**
     * @return The book's title.
     */
    public String getTitle() {
        return title;
    }

    /**
     * @return The book's chapters, in order.
     */
    public List<Chapter> getChapters() {
        return Collections.unmodifiableList(chapters);
    }

    @Override
    public void accept(TextVisitor v) {
        v.visit(this);
        for (Chapter c : chapters)
            c.accept(v);
    }
}
