package visitor_demo.book;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * Represents a chapter of a book as a title and list of paragraphs.
 * 
 * @author Krysta Yousoufian, CSE 331
 * 
 */
public class Chapter implements Text {
    private String title;
    private List<Paragraph> paragraphs;

    /**
     * @param title
     *            The chapter title.
     * @param paragraphs
     *            The chapter's paragraphs, in order.
     * @effects Constructs a new Chapter with the given title and paragraphs.
     */
    public Chapter(String title, List<Paragraph> paragraphs) {
        this.title = title;
        this.paragraphs = new ArrayList<Paragraph>(paragraphs);
    }

    /**
     * @return The chapter's title.
     */
    public String getTitle() {
        return title;
    }

    /**
     * @return The chapter's paragraphs, in order.
     */
    public List<Paragraph> getParagraphs() {
        return Collections.unmodifiableList(paragraphs);
    }

    @Override
    public void accept(TextVisitor v) {
        v.visit(this);
        for (Paragraph p : paragraphs)
            p.accept(v);
    }
}
