package visitor_demo.printer;

import visitor_demo.book.*;

/**
 * A TextVisitor designed to print out an entire text document in a particular
 * format. (TextVisitors in general could do lots of things with a document
 * besides printing it, such as counting the total number of words or the
 * frequencies of words.)
 * 
 * @author Krysta Yousoufian, CSE 331
 * 
 */
public abstract class PrintVisitor implements TextVisitor {
    protected final StringBuilder textBuilder;

    /**
     * @effects Constructs a new PrintVisitor with no text yet.
     */
    public PrintVisitor() {
        textBuilder = new StringBuilder();
    }

    /**
     * @return The text built so far.
     */
    public String getText() {
        return textBuilder.toString();
    }

    /**
     * @effects Appends the text contained directly in the given Text object to
     *          the text to be printed. This is just the title for a Book or
     *          Chapter and the full text for a Paragraph.
     */
    @Override
    public void visit(Text text) {
        if (text instanceof Book) {
            visitBook((Book) text);
        } else if (text instanceof Chapter) {
            visitChapter((Chapter) text);
        } else if (text instanceof Paragraph) {
            visitParagraph((Paragraph) text);
        }
    }

    /**
     * @effects Appends the book's title to the text to be printed.
     * @param book
     *            The book to visit
     */
    protected abstract void visitBook(Book book);
    
    /**
     * @effects Appends the chapter's title to the text to be printed.
     * @param chapter
     *            The chapter to visit
     */
    protected abstract void visitChapter(Chapter chapter);

    /**
     * @effects Appends the paragraph's text to the text to be printed.
     * @param pgph
     *            The paragraph to visit
     */
    protected abstract void visitParagraph(Paragraph pgph);
}
